@@ -7,9 +7,6 @@ from compas.datastructures import VolMesh
 from compas.geometry import centroid_points
 from compas.geometry import normalize_vector
 
-from compas_rhino.artists import VolMeshArtist
-
-
 __all__ = ['VolMesh3gs']
 
 
@@ -161,6 +158,56 @@ class VolMesh3gs(VolMesh):
             self.vertex_attribute(vertex, 'y', new_xyz[1])
             self.vertex_attribute(vertex, 'z', new_xyz[2])
 
+    # --------------------------------------------------------------------------
+    # halfface
+    # --------------------------------------------------------------------------
+
+    def boundary_halfface_manifold_neighbors(self, halfface):
+        if not self.is_halfface_on_boundary(halfface):
+            return
+
+        nbrs = []
+        cell = self.halfface_cell(halfface)
+        for u, v in self.halfface_halfedges(halfface):
+            nbr_halfface = self._cell[cell][v][u]
+            w = self.halfface_vertex_ancestor(nbr_halfface, v)
+            nbr_cell = self._plane[u][v][w]
+            if nbr_cell is not None:
+                nbr = self._cell[nbr_cell][v][u]
+                nbrs.append(nbr)
+        return nbrs
+
+        # nbrs = []
+        # cell = self.halfface_cell(halfface)
+        # for halfedge in self.halfface_halfedges(halfface):
+        #     print('halfedge', halfedge)
+        #     print('edge halffaces', self.edge_halffaces(halfedge))
+
+        #     for face in self.edge_halffaces(halfedge):
+        #         print('face -------------------------', face)
+        #         if self.is_halfface_on_boundary(face):
+        #             print('cell', cell)
+        #             print('nbr_ckey', self.halfface_cell(face))
+
+        #             if self.halfface_cell(face) is not cell:
+        #                 print('add face')
+        #                 nbrs.append(face)
+        # print('nbrs', nbrs)
+        # return nbrs
+
+    def boundary_halfface_manifold_neighborhood(self, hfkey, ring=1):
+        nbrs = set(self.boundary_halfface_manifold_neighbors(hfkey))
+        i = 1
+        while True:
+            if i == ring:
+                break
+            temp = []
+            for nbr_hfkey in nbrs:
+                temp += self.boundary_halfface_manifold_neighbors(hfkey)
+            nbrs.update(temp)
+            i += 1
+        return list(nbrs - set([hfkey]))
+
     # --------------------------------------------------------------------------
     # cell
     # --------------------------------------------------------------------------
@@ -187,50 +234,50 @@ class VolMesh3gs(VolMesh):
             if nbr == cell_2:
                 return halfface, self.halfface_opposite_halfface(halfface)
 
-        return
+        raise KeyError
 
     # --------------------------------------------------------------------------
     # drawing
     # --------------------------------------------------------------------------
 
-    def draw(self, **kwattr):
-        artist = VolMeshArtist(self, layer=self.layer)
-        artist.clear_by_name()
-        artist.draw_faces(**kwattr)
-        artist.draw_vertices(**kwattr)
+    # def draw(self, **kwattr):
+    #     artist = VolMeshArtist(self, layer=self.layer)
+    #     artist.clear_by_name()
+    #     artist.draw_faces(**kwattr)
+    #     artist.draw_vertices(**kwattr)
 
-    def clear(self, **kwattr):
-        artist = VolMeshArtist(self, layer=self.layer)
-        artist.clear_by_name()
-        artist.clear_layer()
+    # def clear(self, **kwattr):
+    #     artist = VolMeshArtist(self, layer=self.layer)
+    #     artist.clear_by_name()
+    #     artist.clear_layer()
 
-    def draw_edges(self, **kwattr):
-        artist = VolMeshArtist(self, **kwattr)
-        artist.draw_edges(**kwattr)
+    # def draw_edges(self, **kwattr):
+    #     artist = VolMeshArtist(self, **kwattr)
+    #     artist.draw_edges(**kwattr)
 
-    def draw_faces(self, **kwattr):
-        artist = VolMeshArtist(self, layer=self.layer)
-        artist.draw_faces(**kwattr)
+    # def draw_faces(self, **kwattr):
+    #     artist = VolMeshArtist(self, layer=self.layer)
+    #     artist.draw_faces(**kwattr)
 
-    def clear_faces(self, **kwattr):
-        artist = VolMeshArtist(self, layer=self.layer)
-        artist.clear_faces(**kwattr)
+    # def clear_faces(self, **kwattr):
+    #     artist = VolMeshArtist(self, layer=self.layer)
+    #     artist.clear_faces(**kwattr)
 
-    def draw_facelabels(self, **kwattr):
-        artist = VolMeshArtist(self, layer=self.layer)
-        artist.draw_facelabels(**kwattr)
+    # def draw_facelabels(self, **kwattr):
+    #     artist = VolMeshArtist(self, layer=self.layer)
+    #     artist.draw_facelabels(**kwattr)
 
-    def draw_vertices(self, **kwattr):
-        artist = VolMeshArtist(self, layer=self.layer)
-        artist.draw_vertices(**kwattr)
+    # def draw_vertices(self, **kwattr):
+    #     artist = VolMeshArtist(self, layer=self.layer)
+    #     artist.draw_vertices(**kwattr)
 
-    def draw_vertexlabels(self, **kwattr):
-        artist = VolMeshArtist(self, layer=self.layer)
-        artist.draw_vertexlabels(**kwattr)
+    # def draw_vertexlabels(self, **kwattr):
+    #     artist = VolMeshArtist(self, layer=self.layer)
+    #     artist.draw_vertexlabels(**kwattr)
 
-    def draw_edgelabels(self, **kwattr):
-        artist = VolMeshArtist(self, layer=self.layer)
-        artist.draw_edgelabels(**kwattr)
+    # def draw_edgelabels(self, **kwattr):
+    #     artist = VolMeshArtist(self, layer=self.layer)
+    #     artist.draw_edgelabels(**kwattr)
 
 
 # ******************************************************************************
