@@ -2,7 +2,7 @@ from __future__ import absolute_import
 from __future__ import print_function
 from __future__ import division
 
-from .conduits import *
-from .drawing import *
+from .conduits import *  # noqa: F401 F403
+from .drawing import *  # noqa: F401 F403
 
 __all__ = [name for name in dir() if not name.startswith('_')]
