@@ -9,12 +9,11 @@ from compas.geometry import add_vectors
 from compas.geometry import scale_vector
 from compas.geometry import subtract_vectors
 from compas.geometry import normalize_vector
+from compas.geometry import length_vector
 
 from compas.utilities import i_to_green
 from compas.utilities import color_to_colordict
 
-from compas_rhino.utilities import delete_objects
-
 from compas_3gs.algorithms import volmesh_ud
 
 from compas_3gs.utilities import pair_uv_to_hf
@@ -115,7 +114,8 @@ def draw_vertex_fixities(diagram):
             color_dict[vertex] = (r, g, b)
 
     diagram.draw()
-    diagram.draw_vertexlabels(text=text_dict, color=color_dict)
+    guids = diagram.draw_vertexlabels(text=text_dict, color=color_dict)
+    return guids
 
 
 # ******************************************************************************
@@ -177,7 +177,9 @@ def draw_cell_force_vectors(volmesh, ckey):
             'color': (0, 255, 0),
             'name': 'hfkey.{}'.format(hfkey)})
 
-    compas_rhino.draw_lines(lines)
+    guids = compas_rhino.draw_lines(lines)
+
+    return guids
 
 
 def draw_cell_labels(volmesh, ckeys=None, text=None, color=None):
@@ -222,10 +224,11 @@ def draw_cell_labels(volmesh, ckeys=None, text=None, color=None):
             'text': textdict[ckey]})
 
     # 4. draw ------------------------------------------------------------------
-    compas_rhino.draw_labels(labels,
-                             layer=volmesh.layer,
-                             clear=False,
-                             redraw=False)
+    guids = compas_rhino.draw_labels(labels,
+                                     layer=volmesh.layer,
+                                     clear=False,
+                                     redraw=False)
+    return guids
 
 
 def clear_cell_labels(volmesh, ckeys=None):
@@ -247,7 +250,8 @@ def clear_cell_labels(volmesh, ckeys=None):
             name = '*.cell.label.{}'.format(key)
             guid = compas_rhino.get_object(name=name)
             guids.append(guid)
-    compas_rhino.delete_objects(guids)
+    guids = compas_rhino.delete_objects(guids)
+    return guids
 
 
 # ******************************************************************************
@@ -279,7 +283,8 @@ def draw_volmesh_cells(volmesh,
         for hfkey in halffaces:
             hfkeys.append(hfkey)
 
-    volmesh.draw_faces(faces=hfkeys, color=hf_colordict)
+    guids = volmesh.draw_faces(faces=hfkeys, color=hf_colordict)
+    return guids
 
 
 def draw_volmesh_face_normals(volmesh,
@@ -329,10 +334,11 @@ def draw_volmesh_face_normals(volmesh,
             'name': name})
 
     # 3. draw ------------------------------------------------------------------
-    compas_rhino.draw_lines(f_normals,
-                            layer=volmesh.layer,
-                            clear=False,
-                            redraw=False)
+    guids = compas_rhino.draw_lines(f_normals,
+                                    layer=volmesh.layer,
+                                    clear=False,
+                                    redraw=False)
+    return guids
 
 
 def draw_volmesh_UD(volmesh,
@@ -382,11 +388,12 @@ def draw_volmesh_UD(volmesh,
                               'color': color})
 
     # 4. draw ------------------------------------------------------------------
-    compas_rhino.draw_faces(faces,
-                            layer=volmesh.layer,
-                            clear=False,
-                            redraw=False)
+    guids = compas_rhino.draw_faces(faces,
+                                    layer=volmesh.layer,
+                                    clear=False,
+                                    redraw=False)
 
+    return guids
 
 # ******************************************************************************
 # ******************************************************************************
@@ -401,7 +408,6 @@ def draw_volmesh_UD(volmesh,
 
 def draw_network_external_forces(volmesh,
                                  network,
-                                 vkeys=[],
                                  gradient=True,
                                  scale=1.0):
     """Draws the boundary forces on the form diagram.
@@ -412,66 +418,111 @@ def draw_network_external_forces(volmesh,
         A volmesh datastructure representing a polyhedral force diagram.
     network : network object
         A network datastructure representing a polyhedral form diagram.
-    vkeys : list, optional
-        List of vertex keys to draw the boundary forces for.
     scale : float, optional
         Drawing scale factor for the boundary forces.
 
     """
-    # 2. get boundary hfs ------------------------------------------------------
-    hfkeys = volmesh.halffaces_on_boundaries()
 
-    # 1. delete any existing boundary forces -----------------------------------
-    name = '*.edge.loads.*'
-    delete_objects(compas_rhino.get_objects(name=name))
+    load_vectors = {}
+    load_mags = {}
 
-    # evaluate specified vertices
-    if vkeys:
-        temp_hfs = []
-        for vkey in vkeys:
-            cell_hfs = volmesh.cell_halffaces(vkey)
-            for cell_hf in cell_hfs:
-                if cell_hf in hfkeys:
-                    temp_hfs.append(cell_hf)
-        if not temp_hfs:
-            return
-        hfkeys = temp_hfs
+    for cell in volmesh.cells_on_boundaries():
+        vectors = []
+        for face in volmesh.cell_faces(cell):
+            if volmesh.is_halfface_on_boundary(face):
+                vectors.append(volmesh.halfface_normal(face, unitized=False))
 
-    # 3. get hf areas and colors -----------------------------------------------
-    hf_areas = {hfkey: volmesh.halfface_area(hfkey) for hfkey in hfkeys}
+        vectors = zip(*vectors)
+        resultant = [sum(vector) for vector in vectors]
+        load_vectors[cell] = resultant
+        load_mags[cell] = length_vector(resultant)
 
-    hf_c_dict = {}
-    if gradient:
-        hf_c_dict = valuedict_to_colordict(hf_areas, color_scheme=i_to_green)
+    # get green gradient
+    colordict = valuedict_to_colordict(load_mags, color_scheme=i_to_green)
 
-    colordict = color_to_colordict(hf_c_dict,
-                                   hfkeys,
-                                   default=(0, 255, 0),
-                                   colorformat='rgb',
-                                   normalize=False)
-
-    # 4. forces and labels to draw ---------------------------------------------
     lines = []
-    for hfkey in hfkeys:
-        ckey = volmesh.halfface_cell(hfkey)
-        normal = volmesh.halfface_normal(hfkey, unitized=False)
-        area = hf_areas[hfkey],
-        vector = scale_vector(normal, scale)
-        sp = network.vertex_coordinates(ckey)
+    for vertex in load_vectors:
+        vector = scale_vector(load_vectors[vertex], scale)
+        sp = network.vertex_coordinates(vertex)
         ep = add_vectors(sp, vector)
-        color = colordict[hfkey]
+        if volmesh.attributes['convention'] == -1:
+            sp, ep = ep, sp
+        color = (0, 100, 0)
+        if gradient:
+            color = colordict[vertex]
         lines.append({
             'start': sp,
             'end': ep,
             'color': color,
             'arrow': 'end',
-            'name': '{}.edge.loads.{}.{}'.format(network.name, hfkey, area)})
+            'name': '{}.load.at.vertex.{}'.format(network.name, vertex)})
 
     # 5. draw ------------------------------------------------------------------
-    compas_rhino.draw_lines(lines,
-                            layer=network.layer,
-                            clear=False,
-                            redraw=False)
+    return compas_rhino.draw_lines(lines,
+                                   layer=network.layer,
+                                   clear=False,
+                                   redraw=False)
+
+    # # # 2. get boundary hfs ------------------------------------------------------
+    # hfkeys = volmesh.halffaces_on_boundaries()
+
+    # # # 1. delete any existing boundary forces -----------------------------------
+    # # name = '*.edge.loads.*'
+    # # delete_objects(compas_rhino.get_objects(name=name))
+
+    # # # evaluate specified vertices
+    # # if vkeys:
+    # #     temp_hfs = []
+    # #     for vkey in vkeys:
+    # #         cell_hfs = volmesh.cell_halffaces(vkey)
+    # #         for cell_hf in cell_hfs:
+    # #             if cell_hf in hfkeys:
+    # #                 temp_hfs.append(cell_hf)
+    # #     if not temp_hfs:
+    # #         return
+    # #     hfkeys = temp_hfs
+
+    # # 3. get hf areas and colors -----------------------------------------------
+    # hf_areas = {hfkey: volmesh.halfface_area(hfkey) for hfkey in hfkeys}
+
+    # hf_c_dict = {}
+    # if gradient:
+    #     hf_c_dict = valuedict_to_colordict(hf_areas, color_scheme=i_to_green)
+
+    # colordict = color_to_colordict(hf_c_dict,
+    #                                hfkeys,
+    #                                default=(0, 255, 0),
+    #                                colorformat='rgb',
+    #                                normalize=False)
+
+    # # 4. forces and labels to draw ---------------------------------------------
+    # lines = []
+    # for hfkey in hfkeys:
+    #     ckey = volmesh.halfface_cell(hfkey)
+    #     normal = volmesh.halfface_normal(hfkey, unitized=False)
+    #     area = hf_areas[hfkey]
+    #     vector = scale_vector(normal, scale)
+
+    #     sp = network.vertex_coordinates(ckey)
+    #     ep = add_vectors(sp, vector)
+    #     if volmesh.attributes['convention'] == -1:
+    #         sp, ep = ep, sp
+
+    #     color = colordict[hfkey]
+    #     lines.append({
+    #         'start': sp,
+    #         'end': ep,
+    #         'color': color,
+    #         'arrow': 'end',
+    #         'name': '{}.edge.loads.{}.{}'.format(network.name, hfkey, area)})
+
+    # # 5. draw ------------------------------------------------------------------
+    # guids = compas_rhino.draw_lines(lines,
+    #                                 layer=network.layer,
+    #                                 clear=False,
+    #                                 redraw=False)
+
+    # return guids
 
 
 def draw_network_internal_forces(volmesh,
@@ -521,7 +572,9 @@ def draw_network_internal_forces(volmesh,
                 'name': '{}.edge.force.{}-{}'.format(network.name, u, v)})
 
     # 4. draw force vectors ----------------------------------------------------
-    compas_rhino.draw_lines(arrows)
+    guids = compas_rhino.draw_lines(arrows)
+
+    return guids
 
 
 def draw_network_pipes(volmesh,
@@ -550,8 +603,8 @@ def draw_network_pipes(volmesh,
             'name': '{}.edge.pipes.{}'.format(network.name, uv)})
 
     # 4. draw ------------------------------------------------------------------
-    compas_rhino.draw_cylinders(cylinders, cap=True)
-
+    guids = compas_rhino.draw_cylinders(cylinders, cap=True)
+    return guids
 
 # ******************************************************************************
 # ******************************************************************************
@@ -625,10 +678,12 @@ def draw_directed_uv(datastructure,
             'name': '{}.edge.{}-{}'.format(datastructure.name, u, v)})
 
     # 3. draw network ----------------------------------------------------------
-    compas_rhino.draw_lines(edges,
-                            layer=datastructure.layer,
-                            clear=False,
-                            redraw=False)
+    guids = compas_rhino.draw_lines(edges,
+                                    layer=datastructure.layer,
+                                    clear=False,
+                                    redraw=False)
+
+    return guids
 
 
 def draw_directed_hf_and_uv(volmesh,
