@@ -11,7 +11,7 @@ from compas.geometry import intersection_line_plane
 
 from compas.utilities import i_to_rgb
 
-from compas_rhino.helpers import mesh_select_face
+from compas_rhino.objects import mesh_select_face
 
 from compas_3gs.operations import cell_split_indet_face_vertices
 from compas_3gs.operations import cell_relocate_face
@@ -32,20 +32,14 @@ try:
 
     from System.Drawing.Color import FromArgb
 
-    black          = FromArgb(0, 0, 0)
-    gray           = FromArgb(200, 200, 200)
-    white          = FromArgb(255, 255, 255)
+    black = FromArgb(0, 0, 0)
+    gray = FromArgb(200, 200, 200)
+    white = FromArgb(255, 255, 255)
 
 except ImportError:
     compas.raise_if_ironpython()
 
 
-__author__     = 'Juney Lee'
-__copyright__  = 'Copyright 2019, BLOCK Research Group - ETH Zurich'
-__license__    = 'MIT License'
-__email__      = 'juney.lee@arch.ethz.ch'
-
-
 __all__ = ['rhino_cell_face_pull']
 
 
@@ -75,8 +69,8 @@ def rhino_cell_face_pull(cell):
     # --------------------------------------------------------------------------
     f_normal = cell.face_normal(face)
     f_center = cell.face_center(face)
-    f_area   = cell.face_area(face)
-    f_vkeys  = cell.face_vertices(face)
+    f_area = cell.face_area(face)
+    f_vkeys = cell.face_vertices(face)
 
     # --------------------------------------------------------------------------
     #  3. get neighbor edges and vertex coordinates
@@ -100,16 +94,16 @@ def rhino_cell_face_pull(cell):
 
     def OnDynamicDraw(sender, e):
 
-        cp          = e.CurrentPoint
-        plane       = (cp, f_normal)
+        cp = e.CurrentPoint
+        plane = (cp, f_normal)
         new_pt_list = []
 
         for u in f_vkeys:
-            v           = edges[u]
-            u_xyz       = cell.vertex_coordinates(u)
-            v_xyz       = cell.vertex_coordinates(v)
-            line        = (u_xyz, v_xyz)
-            it          = intersection_line_plane(line, plane)
+            v = edges[u]
+            u_xyz = cell.vertex_coordinates(u)
+            v_xyz = cell.vertex_coordinates(v)
+            line = (u_xyz, v_xyz)
+            it = intersection_line_plane(line, plane)
             xyz_dict[u] = it
             new_pt_list.append(it)
 
@@ -131,40 +125,40 @@ def rhino_cell_face_pull(cell):
         for i in range(-1, len(f_vkeys) - 1):
             vkey1 = f_vkeys[i]
             vkey2 = f_vkeys[i + 1]
-            sp    = Point3d(*cell.vertex_coordinates(vkey1))
-            np    = Point3d(*cell.vertex_coordinates(vkey2))
+            sp = Point3d(*cell.vertex_coordinates(vkey1))
+            np = Point3d(*cell.vertex_coordinates(vkey2))
 
             e.Display.DrawDottedLine(sp, np, black)
 
         # get current face info ------------------------------------------------
-        areas   = {}
+        areas = {}
         normals = {}
         for fkey in cell.faces():
             face_coordinates = [xyz_dict[vkey] for vkey in cell.face_vertices(fkey)]
-            areas[fkey]   = polygon_area_oriented(face_coordinates)
+            areas[fkey] = polygon_area_oriented(face_coordinates)
             normals[fkey] = polygon_normal_oriented(face_coordinates)
 
         # draw new face areas / vectors ----------------------------------------
         for fkey in cell.faces():
-            area   = areas[fkey]
+            area = areas[fkey]
             normal = normals[fkey]
-            value  = area / max(areas.values())
-            color  = i_to_rgb(value)
-            color  = FromArgb(*color)
+            value = area / max(areas.values())
+            color = i_to_rgb(value)
+            color = FromArgb(*color)
 
             # draw vectors -----------------------------------------------------
-            scale  = 0.25
+            scale = 0.25
             center = datastructure_centroid(cell)
-            sp     = Point3d(*center)
+            sp = Point3d(*center)
             vector = scale_vector(normal, area * scale)
-            ep     = Point3d(*add_vectors(center, vector))
+            ep = Point3d(*add_vectors(center, vector))
 
             e.Display.DrawArrow(Line(sp, ep), color, 20, 0)
 
             # draw face --------------------------------------------------------
             face_coordinates = [xyz_dict[vkey] for vkey in cell.face_vertices(fkey)]
             face_coordinates.append(face_coordinates[0])
-            polygon_xyz   = [Point3d(*xyz) for xyz in face_coordinates]
+            polygon_xyz = [Point3d(*xyz) for xyz in face_coordinates]
 
             e.Display.DrawPolyline(polygon_xyz, black, 2)
 
@@ -175,7 +169,7 @@ def rhino_cell_face_pull(cell):
             # display force magnitudes -----------------------------------------
             vector = add_vectors(vector,
                                  scale_vector(normalize_vector(normal), 0.75))
-            xyz    = add_vectors(center, vector)
+            xyz = add_vectors(center, vector)
             if fkey == face:
                 color = black
 
@@ -184,9 +178,9 @@ def rhino_cell_face_pull(cell):
     # --------------------------------------------------------------------------
     #  5. input point
     # --------------------------------------------------------------------------
-    ip   = Point3d(*f_center)
+    ip = Point3d(*f_center)
     line = Rhino.Geometry.Line(ip, ip + Vector3d(*f_normal))
-    gp   = get_target_point(line, OnDynamicDraw)
+    gp = get_target_point(line, OnDynamicDraw)
 
     # --------------------------------------------------------------------------
     #  6. update cell coordinates
