@@ -14,9 +14,8 @@ from compas.geometry import distance_point_point
 from compas.geometry import centroid_points
 from compas.utilities import i_to_rgb
 
-from compas_rhino.objects.select import mesh_select_vertices
-from compas_rhino.objects.select import mesh_select_face
-from compas_rhino.objects.select import mesh_select_faces
+from compas_rhino.objects import mesh_select_vertices
+from compas_rhino.objects import mesh_select_faces
 
 from compas_3gs.operations import volmesh_vertex_merge
 from compas_3gs.operations import volmesh_vertex_lift
@@ -26,7 +25,6 @@ from compas_3gs.operations import volmesh_cell_subdivide_barycentric
 
 from compas_3gs.rhino import VolMeshSelector
 from compas_3gs.rhino import CellSelector
-from compas_3gs.rhino import VolmeshHalffaceInspector
 from compas_3gs.rhino import VolmeshCellInspector
 
 from compas_3gs.rhino import get_target_point
@@ -63,7 +61,7 @@ __all__ = ['rhino_volmesh_vertex_lift',
            'rhino_volmesh_merge_adjacent_halffaces',
 
            'rhino_volmesh_cell_subdivide_barycentric',
-           'rhino_volmesh_pull_boundary_faces']
+           'rhino_volmesh_pull_halffaces']
 
 
 # ******************************************************************************
@@ -209,32 +207,32 @@ def rhino_volmesh_merge_adjacent_halffaces(volmesh):
     return volmesh
 
 
-def rhino_volmesh_pull_boundary_faces(volmesh, uniform=False):
+def rhino_volmesh_pull_halffaces(volmesh, hfkey, uniform=False):
 
-    # --------------------------------------------------------------------------
-    #  1. display boundary halffaces
-    # --------------------------------------------------------------------------
-    boundary_halffaces = volmesh.halffaces_on_boundaries()
+    # # --------------------------------------------------------------------------
+    # #  1. display boundary halffaces
+    # # --------------------------------------------------------------------------
+    # boundary_halffaces = volmesh.halffaces_on_boundaries()
 
-    volmesh.clear()
-    volmesh.draw_edges()
-    volmesh.draw_faces(faces=boundary_halffaces)
+    # volmesh.clear()
+    # volmesh.draw_edges()
+    # volmesh.draw_faces(faces=boundary_halffaces)
 
-    rs.EnableRedraw(True)
+    # rs.EnableRedraw(True)
 
-    # --------------------------------------------------------------------------
-    #  2. select halfface and its dependents
-    # --------------------------------------------------------------------------
-    hf_inspector = VolmeshHalffaceInspector(volmesh,
-                                            hfkeys=boundary_halffaces,
-                                            dependents=True)
-    hf_inspector.enable()
+    # # --------------------------------------------------------------------------
+    # #  2. select halfface and its dependents
+    # # --------------------------------------------------------------------------
+    # hf_inspector = VolmeshHalffaceInspector(volmesh,
+    #                                         hfkeys=boundary_halffaces,
+    #                                         dependents=True)
+    # hf_inspector.enable()
 
-    hfkey = mesh_select_face(volmesh)
+    # hfkey = mesh_select_face(volmesh)
 
-    hf_inspector.disable()
+    # hf_inspector.disable()
 
-    del hf_inspector
+    # del hf_inspector
 
     # hf dependent hfs
 
@@ -323,8 +321,6 @@ def rhino_volmesh_pull_boundary_faces(volmesh, uniform=False):
         coordinates = new_xyz[key]
         volmesh.vertex_update_xyz(key, coordinates, constrained=False)
 
-    volmesh.draw()
-
 
 # ******************************************************************************
 # ******************************************************************************
@@ -385,6 +381,7 @@ def rhino_volmesh_cell_subdivide_barycentric(volmesh, formdiagram=None):
 def _volmesh_compute_dependent_face_intersections(volmesh,
                                                   hfkey,
                                                   xyz,
+
                                                   normal=None):
 
     if not normal:
@@ -392,7 +389,8 @@ def _volmesh_compute_dependent_face_intersections(volmesh,
 
     vertex_xyz = _cell_update_halfface(volmesh, hfkey, xyz, normal)
 
-    dep_hfkeys = _halfface_edge_dependents(volmesh, hfkey)
+    dep_hfkeys = _boundary_halfface_edge_dependents(volmesh, hfkey)
+    # dep_hfkeys = volmesh.halfface_manifold_neighbors(hfkey)
     hf_centers = {}
 
     for nbr_hfkey in dep_hfkeys:
@@ -400,7 +398,8 @@ def _volmesh_compute_dependent_face_intersections(volmesh,
         center_xyz = vertex_xyz[center_key]
         hf_centers[nbr_hfkey] = center_xyz
 
-    dependents = set(_halfface_edge_dependents(volmesh, hfkey).keys())
+    dependents = set(_boundary_halfface_edge_dependents(volmesh, hfkey).keys())
+    # dependents = set(volmesh.halfface_manifold_neighbors(hfkey))
     seen = set()
 
     i = 0
@@ -425,7 +424,7 @@ def _volmesh_compute_dependent_face_intersections(volmesh,
                     if vkey not in vertex_xyz:
                         vertex_xyz[vkey] = next_xyz[vkey]
 
-                next_d_hfkeys = _halfface_edge_dependents(volmesh, d_hfkey)
+                next_d_hfkeys = _boundary_halfface_edge_dependents(volmesh, d_hfkey)
 
                 for fkey in next_d_hfkeys:
                     if fkey not in hf_centers:
@@ -493,10 +492,17 @@ def _volmesh_current_halfface_centers(volmesh):
     return centers
 
 
-def _halfface_edge_dependents(volmesh, hfkey):
+def _boundary_halfface_edge_dependents(volmesh, halfface):
     dep_hfkeys = {}
-    ckey = volmesh.halfface_cell(hfkey)
-    hf_edges = volmesh.halfface_halfedges(hfkey)
+    # cell = volmesh.halfface_cell(halfface)
+    # for halfedge in volmesh.halfface_halfedges(halfface):
+    #     for face in volmesh.edge_halffaces(halfedge):
+    #         if volmesh.is_halfface_on_boundary(face):
+    #             if volmesh.halfface_cell(face) != cell:
+    #                 dep_hfkeys[face] = halfedge[0]
+
+    ckey = volmesh.halfface_cell(halfface)
+    hf_edges = volmesh.halfface_halfedges(halfface)
     for edge in hf_edges:
         u = edge[0]
         v = edge[1]
@@ -509,6 +515,53 @@ def _halfface_edge_dependents(volmesh, hfkey):
     return dep_hfkeys
 
 
+def _boundary_halfface_manifold_neighbors(volmesh, halfface):
+    '''intended for boundary faces only'''
+    nbrs = []
+    cell = volmesh.halfface_cell(halfface)
+    for halfedge in volmesh.halfface_halfedges(halfface):
+        for face in volmesh.edge_halffaces(halfedge):
+            if volmesh.is_halfface_on_boundary(face):
+                if face != halfface:
+                    if volmesh.halfface_cell(face) != cell:
+                        nbrs.append(face)
+    # for u, v in volmesh.halfface_halfedges(halfface):
+    #     nbr_halfface = volmesh._cell[cell][v][u]
+    #     w = volmesh.halfface_vertex_ancestor(nbr_halfface, v)
+    #     nbr_cell = volmesh._plane[u][v][w]
+    #     if nbr_cell is not None:
+    #         nbr = volmesh._cell[nbr_cell][v][u]
+    #         nbrs.append(nbr)
+    return nbrs
+
+
+def _boundary_halfface_manifold_neighborhood(volmesh, hfkey, ring=1):
+    """Return the halfface neighborhood of a halfface across their edges.
+    Parameters
+    ----------
+    key : hashable
+        The identifier of the halfface.
+    Returns
+    -------
+    list
+        The list of neighboring halffaces.
+    Notes
+    -----
+    Neighboring halffaces on the same cell are not included.
+    """
+    nbrs = set(_boundary_halfface_manifold_neighbors(volmesh, hfkey))
+    i = 1
+    while True:
+        if i == ring:
+            break
+        temp = []
+        for nbr_hfkey in nbrs:
+            temp += _boundary_halfface_manifold_neighbors(volmesh, hfkey)
+        nbrs.update(temp)
+        i += 1
+    return list(nbrs - set([hfkey]))
+
+
 def _halffaces_avg_normals(volmesh, hfkeys):
     vectors = []
     for hfkey in hfkeys:
